@@ -438,6 +438,7 @@ class WorkflowEngine:
                                                     if len(replace_value) == 0:
                                                         self.print_log(status="Ending loop",
                                                                        result=f"No items to loop...")
+                                                        val = replace_value
                                                         # self.exitcode_ok()
                                                     else:
                                                         if loopvars[0].counter < len(replace_value):
@@ -487,13 +488,16 @@ class WorkflowEngine:
                                                     val = replace_value
                                         else:
                                             if str(replace_value).__contains__("Message(mime_content="):
+                                                if attr is None:
+                                                    attr=""
                                                 if isinstance(replace_value, list):
                                                     if tv.__contains__("."):
                                                         attr = str(lst[0].split(".")[1]).replace(".", "")
                                                     if loopvars[0].counter <= len(replace_value) - 1:
                                                         val = replace_value[loopvars[0].counter]
-                                                        if len(attr) > 0:
-                                                            val = getattr(val, attr)
+                                                        if attr is not None:
+                                                            if len(attr) > 0:
+                                                                val = getattr(val, attr)
                                                     else:
                                                         val = replace_value[0]
                                                         if len(attr) > 0:
@@ -610,12 +614,14 @@ class WorkflowEngine:
             self.error = True
             raise Exception('Your installation directory is unknown.')
         # Save the flow if not already saved
-        if not os.path.exists(f'{self.db}\\Registered Flows\\{self.flowname}.xml') and not os.path.exists(
-                self.flowpath):
+        # if not os.path.exists(f'{self.db}\\Registered Flows\\{self.flowname}.xml') and not os.path.exists(
+            #   self.flowpath):
             # Move the file to the registered directory if not exists
-            copyfile(self.flowpath, f'{db_path}\\Registered Flows\\{self.flowname}.xml')
-        if not self.flowpath.lower().__contains__(".vsdx"):
-            self.flowpath = f'{db_path}\\Registered Flows\\{self.flowname}.xml'
+            # copyfile(self.flowpath, f'{db_path}\\Registered Flows\\{self.flowname}.xml')
+        # if not self.flowpath.lower().__contains__(".vsdx"):
+        #     self.flowpath = f'{db_path}\\Registered Flows\\{self.flowname}.xml'
+        if not str(self.flowpath).__contains__("\\"):
+            self.flowpath = os.getcwd() + f"\\{self.flowpath}"
         sql = f"SELECT id FROM Flows WHERE name ='{self.flowname}' AND location='{self.flowpath}'"
         flow_id = self.db.run_sql(sql=sql, tablename="Flows")
         if flow_id is None:
@@ -627,7 +633,7 @@ class WorkflowEngine:
         step = [x for x in shape_steps if x.IsStart][0]
 
         # Log the start in the orchestrator database
-        sql = f"INSERT INTO Runs (name, flow_id) VALUES ('{self.flowname}', {flow_id});"
+        sql = f"INSERT INTO Runs (name, flow_id, result) VALUES ('{self.flowname}', {flow_id}, 'The flow was aborted.');"
         self.id = self.db.run_sql(sql=sql, tablename="Runs")
         print("\n")
         self.print_log(status="Starting",
@@ -868,11 +874,12 @@ class WorkflowEngine:
             ok = "The flow has ended with ERRORS."
         sql = f"INSERT INTO Steps (run, name, step, status, result) VALUES ('{self.id}', '{self.flowname}', 'End', 'Ended', '{ok}');"
         step_time = datetime.now().strftime("%H:%M:%S")
+        finished = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
         end_result = f"{step_time}: Flow '{self.flowname}': {ok}"
         print(end_result)
         self.db.run_sql(sql=sql, tablename="Steps")
         # Update the result of the flow
-        sql = f"UPDATE Runs SET result= '{ok}' where id = {self.id};"
+        sql = f"UPDATE Runs SET result= '{ok}', finished='{finished}' where id = {self.id};"
         self.db.run_sql(sql=sql, tablename="Runs")
 
     def get_input_from_signature(self, step: Any, method_to_call: Any) -> Any:
@@ -1127,12 +1134,14 @@ class WorkflowEngine:
     class dynamic_object(object):
         pass
 
-    @staticmethod
-    def set_breakpoint():
+    def set_breakpoint(self):
         """
         Set a breakpoint to debug the code.
         """
         print("---------- Debug ----------")
+        finished = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+        sql = f"UPDATE Runs SET result= 'Encounters a breakpoint.', finished='{finished}' where id = {self.id};"
+        self.db.run_sql(sql=sql, tablename="Runs")
         breakpoint()
 
 
